@@ -8,20 +8,25 @@ import pandas as pd
 from pydantic import Field, NonNegativeFloat, PrivateAttr
 
 from obi_one.core.block import Block
-from obi_one.core.constants import (
+from obi_one.core.exception import OBIONEError
+from obi_one.core.parametric_multi_values import FloatRange
+from obi_one.scientific.blocks.timestamps import SingleTimestamp
+from obi_one.scientific.library.circuit import Circuit
+from obi_one.scientific.library.constants import (
     _DEFAULT_PULSE_STIMULUS_LENGTH_MILLISECONDS,
     _DEFAULT_STIMULUS_LENGTH_MILLISECONDS,
+    _MAX_POISSON_SPIKE_LIMIT,
     _MIN_NON_NEGATIVE_FLOAT_VALUE,
     _MIN_TIME_STEP_MILLISECONDS,
 )
-from obi_one.core.exception import OBIONEError
-from obi_one.core.parametric_multi_values import FloatRange
-from obi_one.scientific.library.circuit import Circuit
 from obi_one.scientific.unions.unions_neuron_sets import (
     NeuronSetReference,
     resolve_neuron_set_ref_to_node_set,
 )
-from obi_one.scientific.unions.unions_timestamps import TimestampsReference
+from obi_one.scientific.unions.unions_timestamps import (
+    TimestampsReference,
+    resolve_timestamps_ref_to_timestamps_block,
+)
 
 # Could be in Stimulus class rather than repeated in SomaticStimulus and SpikeStimulus
 # But for now this keeps it below the other Block references in get_populationthe GUI
@@ -33,16 +38,18 @@ _TIMESTAMPS_OFFSET_FIELD = Field(
     units="ms",
 )
 
-_MAX_POISSON_SPIKE_LIMIT = 5000000
-
 
 class Stimulus(Block, ABC):
-    timestamps: Annotated[
-        TimestampsReference,
-        Field(title="Timestamps", description="Timestamps at which the stimulus is applied."),
-    ]
+    timestamps: (
+        Annotated[
+            TimestampsReference,
+            Field(title="Timestamps", description="Timestamps at which the stimulus is applied."),
+        ]
+        | None
+    ) = None
 
     _default_node_set: str = PrivateAttr(default="All")
+    _default_timestamps: TimestampsReference = PrivateAttr(default=SingleTimestamp(start_time=0.0))
 
     @abstractmethod
     def _generate_config(self) -> dict:
@@ -50,14 +57,17 @@ class Stimulus(Block, ABC):
 
 
 class SomaticStimulus(Stimulus, ABC):
-    neuron_set: Annotated[
-        NeuronSetReference,
-        Field(
-            title="Neuron Set",
-            description="Neuron set to which the stimulus is applied.",
-            supports_virtual=False,
-        ),
-    ]
+    neuron_set: (
+        Annotated[
+            NeuronSetReference,
+            Field(
+                title="Neuron Set",
+                description="Neuron set to which the stimulus is applied.",
+                supports_virtual=False,
+            ),
+        ]
+        | None
+    ) = None
 
     timestamp_offset: float | list[float] | None = _TIMESTAMPS_OFFSET_FIELD
 
@@ -81,9 +91,16 @@ class SomaticStimulus(Stimulus, ABC):
     calculation of the extracellular signal."""
 
     def config(
-        self, circuit: Circuit, population: str | None = None, default_node_set: str = "All"
+        self,
+        circuit: Circuit,
+        population: str | None = None,
+        default_node_set: str = "All",
+        default_timestamps: TimestampsReference = None,
     ) -> dict:
         self._default_node_set = default_node_set
+        if default_timestamps is None:
+            default_timestamps = SingleTimestamp(start_time=0.0)
+        self._default_timestamps = default_timestamps
 
         if (self.neuron_set is not None) and (
             self.neuron_set.block.population_type(circuit, population) != "biophysical"
@@ -115,7 +132,11 @@ class ConstantCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -149,7 +170,11 @@ class RelativeConstantCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -190,7 +215,11 @@ class LinearCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -234,7 +263,11 @@ class RelativeLinearCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -275,7 +308,11 @@ class NormallyDistributedCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -319,7 +356,11 @@ class RelativeNormallyDistributedCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -374,7 +415,11 @@ class MultiPulseCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -427,7 +472,11 @@ class SinusoidalCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -465,7 +514,11 @@ class SubthresholdCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -494,7 +547,11 @@ class HyperpolarizingCurrentClampSomaticStimulus(SomaticStimulus):
     def _generate_config(self) -> dict:
         sonata_config = {}
 
-        for t_ind, timestamp in enumerate(self.timestamps.block.timestamps()):
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for t_ind, timestamp in enumerate(timestamps_block.timestamps()):
             sonata_config[self.block_name + "_" + str(t_ind)] = {
                 "delay": timestamp + self.timestamp_offset,
                 "duration": self.duration,
@@ -513,17 +570,23 @@ class SpikeStimulus(Stimulus):
     _input_type: str = "spikes"
     _spike_file: Path | None = None
     _simulation_length: float | None = None
-    source_neuron_set: Annotated[
-        NeuronSetReference, Field(title="Neuron Set (Source)", supports_virtual=True)
-    ]
-    targeted_neuron_set: Annotated[
-        NeuronSetReference, Field(title="Neuron Set (Target)", supports_virtual=False)
-    ]
+    source_neuron_set: (
+        (Annotated[NeuronSetReference, Field(title="Neuron Set (Source)", supports_virtual=True)])
+        | None
+    ) = None
+    targeted_neuron_set: (
+        Annotated[NeuronSetReference, Field(title="Neuron Set (Target)", supports_virtual=False)]
+        | None
+    ) = None
 
     timestamp_offset: float | list[float] | None = _TIMESTAMPS_OFFSET_FIELD
 
     def config(
-        self, circuit: Circuit, population: str | None = None, default_node_set: str = "All"
+        self,
+        circuit: Circuit,
+        population: str | None = None,
+        default_node_set: str = "All",
+        default_timestamps: TimestampsReference = None,
     ) -> dict:
         self._default_node_set = default_node_set
 
@@ -536,6 +599,10 @@ class SpikeStimulus(Stimulus):
             )
             raise OBIONEError(msg)
 
+        if default_timestamps is None:
+            default_timestamps = SingleTimestamp(start_time=0.0)
+        self._default_timestamps = default_timestamps
+
         return self._generate_config()
 
     def _generate_config(self) -> dict:
@@ -649,10 +716,12 @@ class PoissonSpikeStimulus(SpikeStimulus):
         rng = np.random.default_rng(self.random_seed)
         gids = self.source_neuron_set.block.get_neuron_ids(circuit, source_node_population)
         source_node_population = self.source_neuron_set.block.get_population(source_node_population)
-        timestamps = self.timestamps.block.timestamps()
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
 
         if (
-            self.duration * 1e-3 * len(gids) * self.frequency * len(timestamps)
+            self.duration * 1e-3 * len(gids) * self.frequency * len(timestamps_block.timestamps())
             > _MAX_POISSON_SPIKE_LIMIT
         ):
             msg = (
@@ -662,10 +731,13 @@ class PoissonSpikeStimulus(SpikeStimulus):
             raise OBIONEError(msg)
 
         gid_spike_map = {}
-        for timestamp_idx, timestamp_t in enumerate(timestamps):
+        for timestamp_idx, timestamp_t in enumerate(timestamps_block.timestamps()):
             start_time = timestamp_t + self.timestamp_offset
             end_time = start_time + self.duration
-            if timestamp_idx < len(timestamps) - 1 and not end_time < timestamps[timestamp_idx + 1]:
+            if (
+                timestamp_idx < len(timestamps_block.timestamps()) - 1
+                and not end_time < timestamps_block.timestamps()[timestamp_idx + 1]
+            ):
                 msg = "Stimulus time intervals overlap!"
                 raise ValueError(msg)
             for gid in gids:
@@ -709,8 +781,11 @@ class FullySynchronousSpikeStimulus(SpikeStimulus):
         gids = self.source_neuron_set.block.get_neuron_ids(circuit, source_node_population)
         source_node_population = self.source_neuron_set.block.get_population(source_node_population)
         gid_spike_map = {}
-        timestamps = self.timestamps.block.timestamps()
-        for start_time in timestamps:
+        timestamps_block = resolve_timestamps_ref_to_timestamps_block(
+            self.timestamps, self._default_timestamps
+        )
+
+        for start_time in timestamps_block.timestamps():
             spike = [start_time + self.timestamp_offset]
             for gid in gids:
                 if gid in gid_spike_map:
